@@ -26,7 +26,7 @@ detect_elsevier = function(corpus, sdgs, verbose = FALSE){
     dplyr::select(-sentence) %>%
     dplyr::mutate(document = as.numeric(as.character(doc_id)),
                   feature = as.character(feature),
-                  system = "elsevier")  %>%
+                  system = "Elsevier")  %>%
     dplyr::group_by(document, query_id) %>%
     #paste features together
     dplyr::summarise(number_of_matches = dplyr::n(),
